@@ -1,6 +1,6 @@
 package Hubot::Scripts::shorten;
 {
-  $Hubot::Scripts::shorten::VERSION = '0.0.7';
+  $Hubot::Scripts::shorten::VERSION = '0.0.8';
 }
 use strict;
 use warnings;
@@ -18,7 +18,11 @@ sub load {
         sub {
             my $msg   = shift;
             my $bitly = $msg->match->[0];
-            if ( length $bitly > 50 ) {
+            if (
+                length $bitly > 50
+                && $ENV{HUBOT_BITLY_USERNAME}
+                && $ENV{HUBOT_BITLY_API_KEY}
+            ) {
                 my $uri = URI->new("http://api.bitly.com/v3/shorten");
                 $uri->query_form_hash(
                     login   => $ENV{HUBOT_BITLY_USERNAME},
